;; Generated package description from ivy-posframe.el  -*- no-byte-compile: t -*-
(define-package "ivy-posframe" "0.6.4" "Using posframe to show Ivy" '((emacs "26.0") (posframe "1.0.0") (ivy "0.13.0")) :commit "ede7b2121f176ab543ce6b73fd96e3eafd6d1505" :authors '(("Feng Shu" . "tumashu@163.com") ("Naoya Yamashita" . "conao3@gmail.com")) :maintainer '("Feng Shu" . "tumashu@163.com") :keywords '("abbrev" "convenience" "matching" "ivy") :url "https://github.com/tumashu/ivy-posframe")
